import ctypes


CustomHandle = ctypes.c_uint64


class Flags(ctypes.Structure):
    _fields_ = [("first", ctypes.c_bool), ("second", ctypes.c_bool), ("third", ctypes.c_bool)]


class ApiWrapper:
    def __init__(self, library):
        self.__library = ctypes.cdll.LoadLibrary(library)
        self.__inject("GetHandle", CustomHandle)
        self.__inject("GetFlags", Flags, argtypes=[CustomHandle])

    def __inject(self, name, restype=None, argtypes=None):
        if hasattr(self.__library, name):
            fun = getattr(self.__library, name)
            if restype: fun.restype = restype
            if argtypes: fun.argtypes = argtypes
            setattr(self, name, fun)

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        pass


if __name__ == "__main__":
    with ApiWrapper("APiTest.dll") as api:
        handle = api.GetHandle()
        flags = api.GetFlags(handle)

        print(flags.first)
        print(flags.second)
        print(flags.third)